@@ -1,5 +1,5 @@
 package HTML::Mason::Tests;
-
+$HTML::Mason::Tests::VERSION = '1.60';
 use strict;
 use warnings;
 
@@ -960,8 +960,4 @@ that overrides the _make_interp method to use your subclass:
               %interp_params );
     }
 
-=head1 SEE ALSO
-
-L<HTML::Mason|HTML::Mason>
-
 =cut
